import * as emr from 'aws-cdk-lib/aws-emr';
import * as iam from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
import { WorkSpaceBucket } from './buckets';
/**
 * What kind of authentication the Studio uses.
 */
export declare enum StudioAuthMode {
    /**
                                                           * the Studio authenticates users using AWS SSO.
                                                           */
    AWS_SSO = "SSO",
    /**
                                                           * the Studio authenticates users using AWS IAM.
                                                           */
    AWS_IAM = "IAM"
}
export interface EmrStudioProps {
    /**
                                                   * The custom construct as the workspace S3 bucket.
                                                   **/
    readonly workSpaceBucket: WorkSpaceBucket;
    /**
       * The subnet IDs for the EMR studio.
       * You can select the subnets from the default VPC in your AWS account.
       */
    readonly subnetIds: Array<string>;
    /**
                                                   * Specifies whether the Studio authenticates users using AWS SSO or IAM.
                                                   *
                                                   * @default - StudioAuthMode.AWS_IAM.
                                                   **/
    readonly authMode?: StudioAuthMode;
    /**
                                                           * The ID of the Amazon EMR Studio Engine security group. The Engine security group allows inbound network traffic from the Workspace security group, and it must be in the same VPC specified by VpcId.
                                                           *
                                                           * @default - a security group created by `EmrStudioEngineSecurityGroup`.
                                                           */
    readonly engineSecurityGroupId?: string;
    /**
                                                           * The ID of the security group used by the workspace.
                                                           *
                                                           *  @default - a security group created by `EmrStudioWorkspaceSecurityGroup`.
                                                           */
    readonly workSpaceSecurityGroupId?: string;
    /**
                                                           * A descriptive name for the Amazon EMR Studio.
                                                           *
                                                           * @default - 'emr-sutdio-quicklaunch'
                                                           */
    readonly studioName?: string;
    /**
                                                           * Used by the EMR Studio.
                                                           *
                                                           * @default - 'The default VPC will be used.'
                                                           */
    readonly vpcId?: string;
    /**
                                                           * A detailed description of the Amazon EMR Studio.
                                                           *
                                                           * @default - 'EMR Studio Quick Launch - by scott.hsieh'
                                                           */
    readonly description?: string;
    /**
                                                           * The custom service role for the EMR Studio.
                                                           *
                                                           * @link https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio-service-role.html
                                                           * @default - established by the construct, EmrStudioServiceRole.
                                                           */
    /**
                                                * A name for the service role of an EMR Studio. For valid values, see the RoleName parameter for the CreateRole action in the IAM API Reference.
                                                *
                                                * IMPORTANT: If you specify a name, you cannot perform updates that require replacement of this resource. You can perform updates that require no or some interruption. If you must replace the resource, specify a new name.
                                                *
                                                * If you specify a name, you must specify the CAPABILITY_NAMED_IAM value to acknowledge your template's capabilities. For more information, see Acknowledging IAM Resources in AWS CloudFormation Templates.
                                                *
                                                * @default - 'emr-studio-service-role'
                                                */
    readonly serviceRoleName?: string;
    readonly serviceRoleArn?: string;
    /**
                                                           * The custom user role for the EMR Studio when authentication is AWS SSO.
                                                           *
                                                           * Currently, if you choose to establish an EMR serverless application where the authentication mechanism used by the EMR Studio is AWS SSO, you need to create a user role by yourself and assign the role arn to this argument if AWS SSO is chosen as authentication for the EMR Studio;
                                                           *
                                                           * @link https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio-user-permissions.html
                                                           */
    readonly userRoleArn?: string;
}
export declare class EmrStudio extends Construct {
    readonly entity: emr.CfnStudio;
    constructor(scope: Construct, name: string, props: EmrStudioProps);
    /**
                             * Add `{'for-use-with-amazon-emr-managed-policies', 'true'}` to a specific construct.
                             *
                             * Please refer to [Create an EMR Studio service role](https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio-service-role.html) for detail.
                             * @param entity a construct that is intended to be added the specific tag.
                             */
    private addProperTag;
}
export interface EmrStudioServiceRoleProps {
    /**
                                                   * The custom construct as the workspace S3 bucket.
                                                   **/
    readonly workSpaceBucket: WorkSpaceBucket;
    /**
                                                           * A name for the service role of an EMR Studio. For valid values, see the RoleName parameter for the CreateRole action in the IAM API Reference.
                                                           *
                                                           * IMPORTANT: If you specify a name, you cannot perform updates that require replacement of this resource. You can perform updates that require no or some interruption. If you must replace the resource, specify a new name.
                                                           *
                                                           * If you specify a name, you must specify the CAPABILITY_NAMED_IAM value to acknowledge your template's capabilities. For more information, see Acknowledging IAM Resources in AWS CloudFormation Templates.
                                                           *
                                                           * @default - 'emr-studio-service-role'
                                                           */
    readonly roleName?: string;
}
/**
 * Creates a default service role for an EMR Studio.
 *
 * For detail, please refer to [Create an EMR Studio service role](https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio-service-role.html).
 *
 * ```ts
 * const workSpaceBucket = new WorkSpaceBucket(this, 'WorkSpace');
 * const emrStudioServiceRole = new EmrStudioServiceRole(this, 'Service', {
 *      workSpaceBucket: workSpaceBucket
 * });
 * ```
 */
export declare class EmrStudioServiceRole extends Construct {
    /**
                             * The representative of the default service role for EMR Studio.
                             */
    readonly roleEntity: iam.Role;
    constructor(scope: Construct, name: string, props: EmrStudioServiceRoleProps);
}
//# sourceMappingURL=emr-studio.d.ts.map